@@ -1,10 +1,10 @@
 use crate::relay::ShutdownHandle;
+use crate::tokio::sync::mpsc::{channel, Receiver, Sender};
 use crate::{
     error::Error, relay::RelayMessage, AddressRecord, NodeMessage, NodeReply, NodeReplyResult,
 };
-use ockam_core::compat::collections::BTreeMap;
+use ockam_core::compat::{collections::BTreeMap, vec::Vec};
 use ockam_core::{Address, AddressSet, Result};
-use tokio::sync::mpsc::{channel, Receiver, Sender};
 
 /// A combined address type and local worker router
 ///
